@@ -26,7 +26,6 @@
 #include <span>
 #include <string>
 #include <string_view>
-#include <utility>
 #include <vector>
 
 #include <Wt/Dbo/Dbo.h>
@@ -67,8 +66,9 @@ namespace lms::db
         {
             std::vector<ClusterId> clusters;        // if non empty, tracks that belong to these clusters
             std::vector<std::string_view> keywords; // if non empty, name must match all of these keywords
-            std::string name;                       // if non empty, must match this name
-            std::string stem;                       // if non empty, must match this stem
+            std::string name;                       // if non empty, must match this name (title)
+            std::string fileStem;                   // if non empty, must match this file stem
+            std::string fileName;                   // if non empty, must match this file name
             TrackSortMethod sortMethod{ TrackSortMethod::None };
             std::optional<Range> range;
             Wt::WDateTime writtenAfter;
@@ -102,11 +102,17 @@ namespace lms::db
                 name = _name;
                 return *this;
             }
-            FindParameters& setStem(std::string_view _stem)
+            FindParameters& setFileStem(std::string_view _fileStem)
             {
-                stem = _stem;
+                fileStem = _fileStem;
                 return *this;
             }
+            FindParameters& setFileName(std::string_view _fileName)
+            {
+                fileName = _fileName;
+                return *this;
+            }
+
             FindParameters& setSortMethod(TrackSortMethod _method)
             {
                 sortMethod = _method;
@@ -317,6 +323,7 @@ namespace lms::db
             Wt::Dbo::field(a, _absoluteFilePath, "absolute_file_path");
             Wt::Dbo::field(a, _relativeFilePath, "relative_file_path");
             Wt::Dbo::field(a, _fileStem, "file_stem");
+            Wt::Dbo::field(a, _fileName, "file_name");
             Wt::Dbo::field(a, _fileSize, "file_size");
             Wt::Dbo::field(a, _fileLastWrite, "file_last_write");
             Wt::Dbo::field(a, _fileAdded, "file_added");
@@ -364,6 +371,7 @@ namespace lms::db
         std::filesystem::path _absoluteFilePath; // full path
         std::filesystem::path _relativeFilePath; // relative to root (that may be deleted)
         std::filesystem::path _fileStem;
+        std::filesystem::path _fileName;
         long long _fileSize{};
         Wt::WDateTime _fileLastWrite;
         Wt::WDateTime _fileAdded;
