@@ -20,6 +20,7 @@
 #pragma once
 
 #include <cstddef>
+#include <span>
 #include <string_view>
 
 namespace lms::image
@@ -31,8 +32,7 @@ namespace lms::image
     public:
         virtual ~IEncodedImage() = default;
 
-        virtual const std::byte* getData() const = 0;
-        virtual std::size_t getDataSize() const = 0;
+        virtual std::span<const std::byte> getData() const = 0;
         virtual std::string_view getMimeType() const = 0;
     };
 } // namespace lms::image
\ No newline at end of file
