@@ -30,7 +30,12 @@ namespace lms::image
 {
     void init(const std::filesystem::path& path);
     std::span<const std::filesystem::path> getSupportedFileExtensions();
-    std::unique_ptr<IRawImage> decodeImage(const std::byte* encodedData, std::size_t encodedDataSize);
+
+    std::unique_ptr<IRawImage> decodeImage(std::span<const std::byte> encodedData);
     std::unique_ptr<IRawImage> decodeImage(const std::filesystem::path& path);
-    std::unique_ptr<IEncodedImage> readSvgFile(const std::filesystem::path& path);
+
+    std::unique_ptr<IEncodedImage> readImage(std::span<const std::byte> encodedData, std::string_view mimeType);
+    std::unique_ptr<IEncodedImage> readImage(const std::filesystem::path& path);
+
+    std::unique_ptr<IEncodedImage> encodeToJPEG(const IRawImage& rawImage, unsigned quality);
 } // namespace lms::image
\ No newline at end of file
