@@ -22,7 +22,6 @@
 #include <filesystem>
 
 #include "av/IAudioFile.hpp"
-#include "metadata/IParser.hpp"
 
 #include "ITagReader.hpp"
 
@@ -32,11 +31,11 @@ namespace lms::metadata
     {
     public:
         AvFormatTagReader(const std::filesystem::path& path, bool debug);
-
-    private:
+        ~AvFormatTagReader() override = default;
         AvFormatTagReader(const AvFormatTagReader&) = delete;
         AvFormatTagReader& operator=(const AvFormatTagReader&) = delete;
 
+    private:
         void visitTagValues(TagType tag, TagValueVisitor visitor) const override;
         void visitTagValues(std::string_view tag, TagValueVisitor visitor) const override;
         void visitPerformerTags(PerformerVisitor visitor) const override;
