@@ -19,8 +19,7 @@
 
 #pragma once
 
-#include <optional>
-#include <string>
+#include <string_view>
 
 #include "database/UserId.hpp"
 
