@@ -37,12 +37,11 @@ namespace lms::feedback
     {
     public:
         FeedbackService(boost::asio::io_context& ioContext, db::Db& db);
-        ~FeedbackService();
-
-    private:
+        ~FeedbackService() override;
         FeedbackService(const FeedbackService&) = delete;
         FeedbackService& operator=(const FeedbackService&) = delete;
 
+    private:
         void star(db::UserId userId, db::ArtistId artistId) override;
         void unstar(db::UserId userId, db::ArtistId artistId) override;
         bool isStarred(db::UserId userId, db::ArtistId artistId) override;
@@ -54,8 +53,8 @@ namespace lms::feedback
 
         void star(db::UserId userId, db::ReleaseId releaseId) override;
         void unstar(db::UserId userId, db::ReleaseId releaseId) override;
-        bool isStarred(db::UserId userId, db::ReleaseId releasedId) override;
-        Wt::WDateTime getStarredDateTime(db::UserId userId, db::ReleaseId releasedId) override;
+        bool isStarred(db::UserId userId, db::ReleaseId releaseId) override;
+        Wt::WDateTime getStarredDateTime(db::UserId userId, db::ReleaseId releaseId) override;
         ReleaseContainer findStarredReleases(const FindParameters& params) override;
 
         void setRating(db::UserId userId, db::ReleaseId releaseId, std::optional<db::Rating> rating) override;
@@ -70,7 +69,6 @@ namespace lms::feedback
         void setRating(db::UserId userId, db::TrackId trackId, std::optional<db::Rating> rating) override;
         std::optional<db::Rating> getRating(db::UserId userId, db::TrackId trackId) override;
 
-    private:
         std::optional<db::FeedbackBackend> getUserFeedbackBackend(db::UserId userId);
 
         template<typename ObjType, typename ObjIdType, typename StarredObjType>
