@@ -27,10 +27,7 @@ namespace lms::api::subsonic
 {
     struct ClientInfo
     {
-        std::string ipAddress;
         std::string name;
-        std::string user;
-        std::string password;
         ProtocolVersion version;
     };
 } // namespace lms::api::subsonic
