@@ -19,19 +19,17 @@
 
 #include "Playlist.hpp"
 
+#include "core/String.hpp"
 #include "database/Track.hpp"
 #include "database/TrackList.hpp"
 #include "database/User.hpp"
 
+#include "CoverArtId.hpp"
 #include "SubsonicId.hpp"
 
 namespace lms::api::subsonic
 {
-    using namespace db;
-
-    static const std::string_view reportedDummyDate{ "2000-01-01T00:00:00" };
-
-    Response::Node createPlaylistNode(const TrackList::pointer& tracklist, Session& session)
+    Response::Node createPlaylistNode(const db::TrackList::pointer& tracklist, db::Session& session)
     {
         Response::Node playlistNode;
 
@@ -39,18 +37,21 @@ namespace lms::api::subsonic
         playlistNode.setAttribute("name", tracklist->getName());
         playlistNode.setAttribute("songCount", tracklist->getCount());
         playlistNode.setAttribute("duration", std::chrono::duration_cast<std::chrono::seconds>(tracklist->getDuration()).count());
-        playlistNode.setAttribute("public", tracklist->isPublic());
-        playlistNode.setAttribute("created", reportedDummyDate);
-        playlistNode.setAttribute("owner", tracklist->getUser()->getLoginName());
+        playlistNode.setAttribute("public", tracklist->getVisibility() == db::TrackList::Visibility::Public);
+        playlistNode.setAttribute("changed", core::stringUtils::toISO8601String(tracklist->getLastModifiedDateTime()));
+        playlistNode.setAttribute("created", core::stringUtils::toISO8601String(tracklist->getCreationDateTime()));
+        if (const db::User::pointer user{ tracklist->getUser() })
+            playlistNode.setAttribute("owner", user->getLoginName());
 
         db::Track::FindParameters params;
         params.setTrackList(tracklist->getId());
         params.setHasEmbeddedImage(true);
         params.setRange(db::Range{ 0, 1 });
-        params.setSortMethod(TrackSortMethod::TrackList);
+        params.setSortMethod(db::TrackSortMethod::TrackList);
 
         db::Track::find(session, params, [&](const db::Track::pointer& track) {
-            playlistNode.setAttribute("coverArt", idToString(track->getId()));
+            const CoverArtId coverArtId{ track->getId(), track->getLastWriteTime().toTime_t() };
+            playlistNode.setAttribute("coverArt", idToString(coverArtId));
         });
 
         return playlistNode;
