@@ -116,6 +116,8 @@ namespace lms::ui
                 return Wt::WString::tr("Lms.Admin.ScannerController.cannot-read-image-file");
             case scanner::ScanErrorType::CannotReadLyricsFile:
                 return Wt::WString::tr("Lms.Admin.ScannerController.cannot-read-lyrics-file");
+            case scanner::ScanErrorType::CannotReadPlayListFile:
+                return Wt::WString::tr("Lms.Admin.ScannerController.cannot-read-playlist-file");
             case scanner::ScanErrorType::NoAudioTrack:
                 return Wt::WString::tr("Lms.Admin.ScannerController.no-audio-track");
             case scanner::ScanErrorType::BadDuration:
@@ -274,6 +276,11 @@ namespace lms::ui
                                      .arg(stepStats.progress()));
             break;
 
+        case ScanStep::AssociatePlayListTracks:
+            _stepStatus->setText(Wt::WString::tr("Lms.Admin.ScannerController.step-associating-playlist-tracks")
+                                     .arg(stepStats.progress()));
+            break;
+
         case ScanStep::AssociateReleaseImages:
             _stepStatus->setText(Wt::WString::tr("Lms.Admin.ScannerController.step-associating-release-images")
                                      .arg(stepStats.progress()));
