@@ -19,6 +19,7 @@
 
 #include "TrackListsView.hpp"
 
+#include <Wt/WLineEdit.h>
 #include <Wt/WPushButton.h>
 
 #include "database/Session.hpp"
@@ -44,16 +45,38 @@ namespace lms::ui
         addFunction("id", &Wt::WTemplate::Functions::id);
 
         {
-            _mode = state::readValue<Mode>("tracklists_sort_mode").value_or(_defaultMode);
+            _type = state::readValue<Type>("tracklists_type").value_or(_defaultType);
 
-            using SortModeSelector = DropDownMenuSelector<TrackLists::Mode>;
-            SortModeSelector* sortModeSelector{ bindNew<SortModeSelector>("sort-mode", Wt::WString::tr("Lms.Explore.TrackLists.template.sort-mode"), _mode) };
-            sortModeSelector->bindItem("recently-modified", Wt::WString::tr("Lms.Explore.recently-modified"), Mode::RecentlyModified);
-            sortModeSelector->bindItem("all", Wt::WString::tr("Lms.Explore.all"), Mode::All);
+            using TypeSelector = DropDownMenuSelector<Type>;
+            TypeSelector* typeSelector{ bindNew<TypeSelector>("tracklist-type", Wt::WString::tr("Lms.Explore.TrackLists.template.type-selector"), _type) };
+            typeSelector->bindItem("owned", Wt::WString::tr("Lms.Explore.TrackLists.type-owned"), Type::Owned);
+            typeSelector->bindItem("shared", Wt::WString::tr("Lms.Explore.TrackLists.type-shared"), Type::Shared);
 
-            sortModeSelector->itemSelected.connect(this, [this](TrackLists::Mode mode) {
-                state::writeValue<Mode>("tracklists_sort_mode", mode);
-                _mode = mode;
+            typeSelector->itemSelected.connect(this, [this](Type type) {
+                state::writeValue<Type>("tracklists_type", type);
+                _type = type;
+                refreshView();
+            });
+        }
+
+        Wt::WLineEdit* searchEdit{ bindNew<Wt::WLineEdit>("search") };
+        searchEdit->setPlaceholderText(Wt::WString::tr("Lms.Explore.Search.search-placeholder"));
+        searchEdit->textInput().connect([this, searchEdit] {
+            _searchText = searchEdit->text().toUTF8();
+            refreshView();
+        });
+
+        {
+            _sortMode = state::readValue<SortMode>("tracklists_sort_mode").value_or(_defaultSortMode);
+
+            using SortModeSelector = DropDownMenuSelector<SortMode>;
+            SortModeSelector* sortModeSelector{ bindNew<SortModeSelector>("sort-mode", Wt::WString::tr("Lms.Explore.TrackLists.template.sort-mode"), _sortMode) };
+            sortModeSelector->bindItem("recently-modified", Wt::WString::tr("Lms.Explore.recently-modified"), SortMode::RecentlyModified);
+            sortModeSelector->bindItem("all", Wt::WString::tr("Lms.Explore.all"), SortMode::All);
+
+            sortModeSelector->itemSelected.connect(this, [this](SortMode mode) {
+                state::writeValue<SortMode>("tracklists_sort_mode", mode);
+                _sortMode = mode;
                 refreshView();
             });
         }
@@ -94,17 +117,32 @@ namespace lms::ui
         auto transaction{ session.createReadTransaction() };
 
         TrackList::FindParameters params;
+
+        if (!_searchText.empty())
+            params.setKeywords(core::stringUtils::splitString(_searchText, ' '));
         params.setClusters(_filters.getClusters());
         params.setMediaLibrary(_filters.getMediaLibrary());
-        params.setUser(LmsApp->getUserId());
-        params.setType(TrackListType::Playlist);
+        params.setType(TrackListType::PlayList);
         params.setRange(range);
-        switch (_mode)
+
+        switch (_type)
         {
-        case Mode::All:
+        case Type::Owned:
+            params.setUser(LmsApp->getUserId());
+            break;
+
+        case Type::Shared:
+            params.setExcludedUser(LmsApp->getUserId());
+            params.setVisibility(db::TrackList::Visibility::Public);
+            break;
+        }
+
+        switch (_sortMode)
+        {
+        case SortMode::All:
             params.setSortMethod(TrackListSortMethod::Name);
             break;
-        case Mode::RecentlyModified:
+        case SortMode::RecentlyModified:
             params.setSortMethod(TrackListSortMethod::LastModifiedDesc);
             break;
         }
